#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: MonadRandom
version: 0.4.2.3
id: MonadRandom-0.4.2.3-c1a87dea4099c830800b3ad78538235a
key: Monad_CLO5AInWsHZAZxUa5zJXgr
license: OtherLicense
maintainer: Brent Yorgey <byorgey@gmail.com>
synopsis: Random-number generation monad.
description:
    Support for computations which consume random values.
category: Control
author: Cale Gibbard and others
exposed: True
exposed-modules:
    Control.Monad.Random Control.Monad.Random.Class
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/MonadRandom-0.4.2.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/MonadRandom-0.4.2.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/MonadRandom-0.4.2.3
hs-libraries: HSMonadRandom-0.4.2.3-CLO5AInWsHZAZxUa5zJXgr
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
haddock-interfaces: /usr/share/doc/haskell-monadrandom/html/MonadRandom.haddock
haddock-html: /usr/share/doc/haskell-monadrandom/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
